export declare const IS_READ_ONLY = true;
export interface SugGetOptions {
    FUZZY?: true;
    MAX?: number;
}
export declare function transformArguments(key: string, prefix: string, options?: SugGetOptions): Array<string>;
export declare function transformReply(): null | Array<string>;
