import { RedisCommandArguments } from '@redis/client/dist/lib/commands';
interface SynUpdateOptions {
    SKIPINITIALSCAN?: true;
}
export declare function transformArguments(index: string, groupId: string, terms: string | Array<string>, options?: SynUpdateOptions): RedisCommandArguments;
export declare function transformReply(): 'OK';
export {};
