import { SugGetOptions } from './SUGGET';
export { IS_READ_ONLY } from './SUGGET';
export declare function transformArguments(key: string, prefix: string, options?: SugGetOptions): Array<string>;
export interface SuggestionWithScores {
    suggestion: string;
    score: number;
}
export declare function transformReply(rawReply: Array<string> | null): Array<SuggestionWithScores> | null;
