import { Params } from ".";
export declare const IS_READ_ONLY = true;
interface ExplainOptions {
    PARAMS?: Params;
    DIALECT?: number;
}
export declare function transformArguments(index: string, query: string, options?: ExplainOptions): Array<string>;
export declare function transformReply(): string;
export {};
