import { RedisCommandArgument } from '@redis/client/dist/lib/commands';
export declare const FIRST_KEY_INDEX = 1;
export declare function transformArguments(index: RedisCommandArgument, cursorId: number): RedisCommandArgument[];
export declare function transformReply(): 'OK';
