export declare function transformArguments(option: string): string[];
interface ConfigGetReply {
    [option: string]: string | null;
}
export declare function transformReply(rawReply: Array<[string, string | null]>): ConfigGetReply;
export {};
