interface DropIndexOptions {
    DD?: true;
}
export declare function transformArguments(index: string, options?: DropIndexOptions): Array<string>;
export declare function transformReply(): 'OK';
export {};
